Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/model/collisionmesh.h')
-rw-r--r--src/model/collisionmesh.h14
1 files changed, 12 insertions, 2 deletions
diff --git a/src/model/collisionmesh.h b/src/model/collisionmesh.h
index e80774d..c1f9846 100644
--- a/src/model/collisionmesh.h
+++ b/src/model/collisionmesh.h
@@ -72,6 +72,10 @@ public:
return collisionmesh_axis;
}
+ inline const math::Vector3f &movement() const {
+ return collisionmesh_movement;
+ }
+
inline const float speed() const {
return collisionmesh_speed;
}
@@ -105,12 +109,16 @@ public:
collisionmesh_axis.assign(axis);
}
+ inline void set_movement(const math::Vector3f &movement) {
+ collisionmesh_movement.assign(movement);
+ }
+
/**
* @brief apply FragmentGroup parameters to the mesh
* This method applies the fragmentgroups type, location, axis, distance, speed and scale
* to the collision mesh
*/
- void set_params(const FragmentGroup *group);
+ void set_params(const FragmentGroup &group);
/**
* @brief movement speed
@@ -147,6 +155,8 @@ private:
math::Vector3f collisionmesh_location;
math::Axis collisionmesh_axis;
+ math::Vector3f collisionmesh_movement;
+
float collisionmesh_speed;
float collisionmesh_scale;
float collisionmesh_distance;
@@ -105,12 +109,16 @@ public:
/**
* @brief apply FragmentGroup parameters to the mesh
- * This method applies the fragmentgroups type, location, axis, distance, speed and scale
+ * This method applies the fragmentgroups type, location, axis, movement, distance, speed and scale
* to the collision mesh
*/